#
# spec file for package lite-xl-plugin-manager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define baseprogramname lite-xl
Name:           lite-xl-plugin-manager
Version:        1.3.1+git20241110.cde491b
Release:        1.3
Summary:        A %{baseprogramname} plugin manager
%if 0%{?suse_version} > 1500
%else
Group:          Productivity/Text/Editors
%endif
License:        Apache-2.0 AND BSD-3-Clause AND MIT AND Zlib AND SUSE-GPL-2.0-with-linking-exception
URL:            https://github.com/lite-xl/lite-xl-plugin-manager
Source:         %{name}-%{version}.tar.gz
Patch0:         lpm.c.diff
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150600
BuildRequires:  mbedtls-2-devel
%else
BuildRequires:  mbedtls-devel
%endif
BuildRequires:  meson
BuildRequires:  pkgconfig(libgit2)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(lua) >= 5.4
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(zlib)
Requires:       %{baseprogramname}
# This can be managed by 'lite-xl-plugin-manager' (lpm)
#Requires:       lite-xl-widgets

%description
* A standalone binary that provides an easy way of installing, and uninstalling
  plugins from lite-xl, as well as different version of lite-xl.
* Can be used by a package manager plugin that works from inside the editor and
  calls this binary.
* Also contains a plugin_manager.lua plugin to integrate the binary with lite
  in the form of an easy-to-use GUI.
* By default in releases, lpm will automatically consume the manifest.json in
  the latest branch of this repository, which corresponds to the most recent versioned release.
* Conforms to SCPS3.

%prep
%autosetup -p 0

%build
%meson -Dstatic=true
%meson_build

%install
%ifarch i586
install -D -m 0755 "i586-suse-linux/lpm" "%{buildroot}/%{_bindir}/lpm"
%else
install -D -m 0755 "%{_arch}-suse-linux/lpm" "%{buildroot}/%{_bindir}/lpm"
%endif

%files
%{_bindir}/lpm
%license LICENSE
%doc README.md CHANGELOG.md

%changelog
* Fri Nov 29 2024 scott.bradnick@suse.com
- Update to version 1.3.1+git20241110.cde491b:
  * Fixed error around get_repository_addons cache.
  * Sigh.
  * Possible link order fix.
  * Signedness issue.
  * Added warnings for fetching https repositories when we don't have the network active.
  * Allows for accessible false variables.
  * Split off compile options to disable large portions of lpm if you don't want to build them.
  * Add option to install Lite-XL plugin (#138)
  * Added in -DLPM_NO_THREADS.
  * reformat executable statement, make installable (#137)
* Fri Nov  8 2024 scott.bradnick@suse.com
- Update to version 1.3.1+git20241108.d1a84c7:
  * Updated CHANGELOG.md.
  * Disabled switch if no default release url.
  * Fixed up tests.
  * Changed erroneous return; thanks to Jan for reporting.
  * Ensured that "any" was being respected.
* Sun Oct 20 2024 scott.bradnick@suse.com
- Update to version 1.3.0+git20241019.3de92ec:
  * Added liblzma to list.
  * Removed encoders for lzma.
  * Updated CHANGELOG.md.
  * Properly determined mod_version of lite-xl.
  * Reported actual improvement.
  * Update CHANGELOG.md.
  * Added in small optimization.
  * Fixed small issue.
  * Fixed some config stuff.
  * Adding in ability to set mod-version "any".
  * Add `lzma` dependency to `meson.build` (#129)
  * Test?
  * Specifically made include directories non-relative.
  * Fix windows and linux compiles.
  * Updated spec to include xz.
  * Added in libxz support, because this keeps coming up.
* Mon Oct 14 2024 scott.bradnick@suse.com
- Update to version 1.2.9+git20241014.13d213a:
  * Small changes to microtar, fixed some issues with the long names in the extract code.
  * Fixed issue with fetch not receiving final progress update.
  * Only insert lite-xls in priority order.
  * Ensures that we actually get all lpm output.
  * Added in fix for handling different versions of lite-xl.
  * Update README.md
  * Added a Scoop install manifest (#123)
  * Added in override for mod_version on system lite-xl.
  * Change names of types so that mac doesn't cry.
  * Fixed windows non-blocking.
  * Made C mutli-threading possible.
* Tue Jul 23 2024 scott.bradnick@suse.com
- Update to version 1.2.9+git20240723.1564bb1:
  * Stopped backfilling path for stubs.
  * Should be more robust at detecthing orphans.
  * Don't allow stubs to override non-stubs in our potential dependency list.
  * Removed duplicatge line.
* Sat Jun 22 2024 scott.bradnick@suse.com
- Update to version 1.2.9+git20240622.1cf4f05:
  * Fixing an error with libzip on newer gcc versions.
  * windows:fix argument escaping for cmd.exe (#117)
* Tue Jun 11 2024 scott.bradnick@suse.com
- Update to version 1.2.9+git20240609.d737011:
  * ci: parallelize most build processes (#115)
  * Added in specific check for install to guard against "*".
  * Fix for Guldo's new issue.
  * Added in fallback to fetch everything if we can't find a specific object.
  * Relaxed detection of datadir and core plugins to probably fix #112.
* Tue Jun  4 2024 scott.bradnick@suse.com
- Update to version 1.2.9+git20240603.5343f48:
  * Added in searchpath for lib64, which is where libraries get installed sometimes.
* Tue May 28 2024 scott.bradnick@suse.com
- Update to version 1.2.9+git20240513.22152f1:
  * Warn about id mismatches, but otherwise, take the basename of a path.
  * Fixed issue with https://github.com/lite-xl/lite-xl-plugin-manager/issues/110.
  * Fix for issue #112.
  * Add JSON schema for `manifest.json` files (#102)
* Mon May 13 2024 scott.bradnick@suse.com
- Update to version 1.2.9+git20240512.81f1703:
  * Fix meson static lua source generation
  * Updated meson and build.sh to remove source context for LPM_STATIC builds.
  * Made change to ensure that total_objects_or_content_length was > 0.
  * Fixed stuff.
  * Comment.
  * Fixed up a few things.
  * Added in declarative managed plugin functionality to plugin_maanger.
  * Unified syntax.
  * Fixed addons.
  * Added in plugin manager hook.
  * Added in apply.
  * Updated CHANGELOG.md.
* Sun Apr 21 2024 scott.bradnick@suse.com
- Update to version 1.2.9+git20240421.b9723c0:
  * Fixed commas.
  * Made {{ a thing.
  * Made URL more sensible.
  * Updated CHANGELOG.md.
  * Fixed issue with SHOULD_COLOR being set to nil, rather than false.
  * Fixed type inference.
  * Made it so you can run the system bottle.
  * Updated CHANGELOG.md.
  * Changed how url is generated.
  * Made it so that we can access `extra` fields. Closes #107.
  * Fixed author variable position.
  * Updated build to match new environment variable.
  * Gcc as $CC (#108)
* Tue Apr  9 2024 Scott Bradnick <scott.bradnick@suse.com>
- Adjusting for https://github.com/rpm-software-management/rpmlint/pull/1222
- Switching to %%autosetup
* Sat Apr  6 2024 scott.bradnick@suse.com
- Update to version 1.2.7+git20240406.6047bb2:
  * Removed old hack to support jgm's stuff.
  * Changed CFLAGS and LDFLAGS vars in build script to handle Guldo's exotic build configuration.
  * Only return functions from `lpm.run`
  * Fix `lpm.run` not returning executor function
  * Added in logging, and fixed a bug
  * Added in complex plugins, as well as split up command and run.
  * Restructured functions to be more modular, and moved things to globals, so that they can easily be modified by plugins instead of as upvalues. (#105)
  * Restructured functions to be more modular, and moved things to globals, so that they can easily be modified by plugins instead of as upvalues.
* Sun Mar 31 2024 scott.bradnick@suse.com
- Update to version 1.2.7+git20240331.bbd5715:
  * Fix dependency on mbedtls (#104)
* Fri Mar 29 2024 scott.bradnick@suse.com
- Update to version 1.2.7+git20240329.dd06ba2:
  * Updated SPEC to incude `checksum` at an addon level, and added in a warning when explicit repositories are specified, but not used.
  * Changed separator to , from :, due to URLs. Sigh.
  * Fixed handleization.
* Mon Mar 25 2024 scott.bradnick@suse.com
- Update to version 1.2.7+git20240324.42394ee:
  * Updated CHANGELOG.md.
  * Abstrated out handleize.
  * Changed how stubs are reported.
  * Changed how ephemeral bottles work.
* Sat Mar 23 2024 scott.bradnick@suse.com
- Update to version 1.2.6+git20240323.9fe3c05:
  * Fixed issue with headers delivered in multiple reads.
  * Added in ephemeral bottle count, so we only destruct the bottle when the lockfile reads 0.
  * Should fix #100
  * Ensures that we close read handles on files.
* Wed Mar 20 2024 scott.bradnick@suse.com
- Update to version 1.2.6+git20240320.57a17ae:
  * Made sure we set the metatable corectly.
  * Remove unecessary require.
  * Updated CHANGELOG.md.
  * Gave exec access to the internal environment, just like with plugins.
  * Added in ability to execute string literals for ease of automation.
* Mon Mar 18 2024 scott.bradnick@suse.com
- Update to version 1.2.5+git20240317.829c8ec:
  * Updated CHANGELOG.md.
  * Ensured we close filehandles.
  * Added in EXEFILE.
  * Build zlib on windows.
  * Added in a fix to detect windows consoles from cmd.exe.
  * Fixed error on first pull.
  * Update README.md
* Wed Mar 13 2024 scott.bradnick@suse.com
- Update to version 1.2.4+git20240312.f677376:
  * Fixed minor issue.
  * Changed strnstr to strnstr_local because mac apparently has this function defined by default.
  * Fixed some stuff with chunked encoding.
  * Fixed the issue with --.
  * Added in chunked transfer encoding.
  * Added in json prety-printing.
  * Added in ability to grab remote plugins.
  * Refactored argument processing.
  * Changed to PATHSEP, from comma.
  * Added in env variable.
  * Made environment more modular, so lpm plugins can use it correctly.
  * Updated platform list.
  * Remove files that don't match checksums.
  * Removed files that fail checks.
  * Remove unceessary checks which are part of the common.get function.
* Fri Mar  8 2024 scott.bradnick@suse.com
- Update to version 1.2.4+git20240308.78184f8:
  * YOLO CI.
  * Updated CHANGELOG.md.
  * Restricted check of arched files to only non-optional files.
  * Fixed issue with rawget, and removed unecessary checksum.
  * Added in aarch64 support.
* Thu Mar  7 2024 scott.bradnick@suse.com
- Update to version 1.2.3+git20240306.04dcf8e:
  * Set explicit environment.
  * Updated CHANGELOG.md.
  * Messed up pathing.
  * Fixed a minor bug with downloading when downloads get aborted, and also ensured that download messages on small terminals don't go nuts.
  * Flush input buffer before prompt.
  * Should fix bug where we're expecting a string back.
* Mon Mar  4 2024 scott.bradnick@suse.com
- Update to version 1.2.2+git20240303.4ef4e13:
  * Flushed stdin before reading from prompt.
  * Updated workflow to strip title line.
  * Removed File::Slurp.
  * Check to see if new github action works.
  * Updated CHANGELOG.md.
  * Added in ability to explicitly chmod files.
  * Allowed for disabling of self-upgrade.
  * Updated CHANGELOG.md.
  * Fixed things up.
  * Jesus christ, widnows.
  * Wrong function.
  * Simplified ls for windows.
  * Fixed error with allocating buffer.
  * Fixed typo.
  * Added better windows error handling.
  * Fixed things up a bit.
  * Updated to tables for common.get.
  * Added in ability to self-upgrade.
* Fri Mar  1 2024 scott.bradnick@suse.com
- Update to version 1.2.0+git20240301.134c144:
  * Fixed tests.
  * Forgot to switch the rest to array.
  * Possibly addressed issue.
  * Added in --raw, fixed some table stuff, fixed filtering things, and cleaned up documentation.
* Mon Feb 26 2024 scott.bradnick@suse.com
- Update to version 1.2.0+git20240225.45d1d50:
  * Made run notification verbose.
  * Changed bzero to memset, in order to eliminate warnings on windows.
  * Unescaped backslashes.
  * Might fix #64.
  * Should fix #82. Will ensure that progress bars go to 100%% when downloading files.
  * Updated CHANGELOG.md.
  * Added test, and clarified things.
  * Added in warnings when we won't install or unisntall things due to mask.
  * hopefully fixed the memory leak (#83)
  * Fix Windows install issues (#79)
  * Added in initial implementation of --mask.
* Sun Feb 25 2024 scott.bradnick@suse.com
- Update to version 1.1.0+git20240225.f264efb:
  * Added in chcek to ensure that we don't try to double-install dependencies.
  * Threw an explicit error if you try to install a repository with no addons selected.
  * Made hash backwards compatible.
  * Added in ephemeral flag as a determinant for bottle hash construction.
  * Use vendored `microtar` version in `meson.build` (#77)
  * Checks if dependency is core beofore marking it as orphan (#76)
  * Update extract: .tgz and +100 char name support (#73)
* Tue Feb 20 2024 scott.bradnick@suse.com
- Update to version 1.1.0+git20240220.9a37552:
  * Fixed typing mistake.
* Mon Feb 12 2024 scott.bradnick@suse.com
- Update to version 1.1.0+git20240211.78ff363:
  * Updated CHANGELOG.md.
  * Made sure to create folders for files if they don't exist.
  * Allowed addons that don't specify a path, but have files, to download only those files.
* Wed Feb  7 2024 scott.bradnick@suse.com
- Update to version 1.0.14+git20240206.8a1e790:
  * Made paths absolute when adding a lite-xl.
  * Doubled response header buffer, added in better error handling for responses, and added in logging and checksum updating of remote file singletons.
  * Added in update-checksums.
* Sun Jan 28 2024 scott.bradnick@suse.com
- Update to version 1.0.14+git20240128.9189b99:
  * Cleaned up example to use the "proper" hosted version.
  * Added fonts to lpm as a new type.
* Sat Jan 27 2024 scott.bradnick@suse.com
- Update to version 1.0.14+git20240126.74aadee:
  * Updated help.
* Thu Jan 18 2024 scott.bradnick@suse.com
- Update to version 1.0.13+git20240118.cda6773:
  * Removing empty comments.
  * Thing was due to the other thing.
  * Removed looking for main/master; now ask directly what the primary branch is.
* Thu Jan 18 2024 scott.bradnick@suse.com
- Update to version 1.0.13+git20240118.e7bd5c0:
  * Added in for case where branch or commit isn't supplied to local manifest repo with a remote.
  * Added in changes from @parnikkapore to fix ssl certificates in a directory.
* Tue Dec  5 2023 scott.bradnick@suse.com
- Update to version 1.0.13+git20231205.1feceea:
  * Fixed CI.
  * Fixed error around orphan plugins.
  * Fixed uninitialization.
  * Reworded things, incorporated Guldo's changes.
  * Added in extra error handling.
  * Added in loading screen for welcome dialog.
  * Split off loading screen functionality.
  * Added welcome plugin.
  * Fixed fetch_if_not_present.
  * Added in better error handling.
  * Added `fetch_if_not_present` to allow things to function without internet.
  * Added in a hook for terminal to display an lpm repl.
  * Pre-sorted dependency graphs so that we get consistnet outputs.
  * Fixed actual output spacing.
  * Added in repostiory URL for plugin to id calculation.
  * Guldo's spelling fixes.
  * Added in a proper repo_path.
  * Added in repo path.
  * Removed documentation for non-existent command.
  * Added in check for executable.
  * Invalidate cache in appropriate places.
  * Allowed for generate_manifest to be used on local repositories; will automatically pile one into the directory.
  * Won't actually have an error so simplified.
  * Loosened verification for certificates.
  * Flagged the json library as special as well, as it's required for the plugin_manager to run.
  * Fixed typo.
  * Ensured we always pass around options so we can track progress one way or another.
  * Added in fallback for any plugin lacking a modversion to describe themselves as the latest modversion.
  * Fixed color install/uninstall; type filter wasn't even present. Whoops.
  * Fixed typo.
  * Added in support for --ephemeral.
  * Allowed for generation for repos that are just init.lua by guessing the id better.
  * Made unstub idempotent and incorporated a number of jgm's fixes.
  * Fix some spelling and display of `DEFAULT_REPO_URL` in cli help
* Tue Oct 10 2023 scott.bradnick@suse.com
- Update to version 1.0.12+git20231010.8f2cd87:
  * Updated CHANGELOG.md.
  * Added in an unstub and VIEW readme function.
  * Added a close for write.
  * Improve `mbedtls2` detection in meson
* Fri Sep 22 2023 scott.bradnick@suse.com
- Adding lpm.c.diff to set LPM_VERSION instead of "unknown"
- Update to version 1.0.11+git20230917.1a54a85:
  * Added in borders to table output.
  * Bugfix.
  * Added in table output format.
  * Updated continous tag.
  * Prioritized remote definitions.
  * Fixed a number of issues relating to generating READMEs, and running arbitrary lua files.
  * Fixed issues with constructing symlink bottles.
  * Reverted is_stub stuff.
  * Made desribe more modern.
* Mon Sep 11 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of licenses based on the legaldb report
  * Main package is under MIT, however archive contains bundled
    libraries, mostly licensed under BSD-3-Clause, Apache-2.0 and Zlib.
  * Use SUSE-GPL-2.0-with-linking-exception identifier instead of spdx
    which is not recognized
* Sun Sep 10 2023 scott.bradnick@suse.com
- Update to version 1.0.11+git20230910.4129734:
  * Added the ability to unstub plugins.
  * Constructed bottles in the TMP directory, rather than directly in-place.
  * Updated CHANGELOG.md.
  * Fix installing plugins with version containing `.`
  * Don't create user `init.lua` if no custom config was specified
* Thu Sep  7 2023 Scott Bradnick <scott.bradnick@suse.com>
- Leap 15.6 will be using mbedtls for v3 and mbedtls-2 for v2,
  like Tumbleweed
* Sun Aug 27 2023 scott.bradnick@suse.com
- Update to version 1.0.10+git20230827.2452630:
  * Updated CHANGELOG.md.
  * Added in --config flag.
  * Made us clear the entire bottle if we're reconstructing which is a lot safer.
* Fri Aug 18 2023 scott.bradnick@suse.com
- Update to version 1.0.9+git20230818.02b2665:
  * Updated CHANGELOG.md.
  * Minor documentation updates.
  * Made it so we also chmod unzipped gz files.
  * Added .gz to the spec.
  * Allowed for extracting of .gz files without an associated tar.
* Thu Aug 17 2023 scott.bradnick@suse.com
- Update to version 1.0.8+git20230817.6bcc10e:
  * Made things clearer.
  * Added in futureproofing.
  * Add in preprocessor guard for older libgit2 implementations.
- Fixing up 'suse_version' check(s)
* Thu Aug 17 2023 Scott Bradnick <scott.bradnick@suse.com>
- Group has been deprecated for a while now, but 15.5 and possibly 15.6
  will complain about it missing
  * https://fedoraproject.org/wiki/RPMGroups
* Wed Aug 16 2023 Scott Bradnick <scott.bradnick@suse.com>
- .spec updates
  * Adding 'Group' designation
  * Adding 'suse_version' check for mbedtls[-2] BuildRequires
* Wed Aug 16 2023 Scott Bradnick <scott.bradnick@suse.com>
- Incorporating @suntorytimed's i586 install check
* Thu Aug 10 2023 Scott Bradnick <scott.bradnick@suse.com>
- Removing 'Requires: lite-xl-widgets' as that's a plugin that can be installed
  via lpm (or pulled in by other plugins which require it)
* Thu Aug 10 2023 scott.bradnick@suse.com
- Update to version 1.0.8+git20230810.627caff:
  * Should fix issue 36.
  * Updated CHANGELOG.md.
  * Fixed capitalization.
  * Normalized paths to backslashes.
  * Made it so we autoflush stderr, because windows doesn't do this.
  * Added in quick way to just grab and install orphan plugins.
  * Fixed typo.
  * Made -g flag signal whether or not we move to debug builds for cmake.
  * Made sure size comparaisons only occur with files.
  * Moved USERDIR creation down a bit.
* Thu Aug 10 2023 Scott Bradnick <scott.bradnick@suse.com>
- Initial version from upstream
  * See https://github.com/lite-xl/lite-xl-plugins/issues/144
